#!/usr/bin/zsh

# Script to create a fully fledged figure from raw data,
# since figures always end up being more complicated than
# they were ever going to be when you wrote the code and 
# made the initial plots!

# See also some scripts for joining up completely
# separate plots into figures... somewhere!

# Root filename of figure
filestring="fig_norm"

# Make a temporary filename without dots and with _tex appended
texfilestring=`echo ${filestring}_tex | sed 's/[.]/_/g'`

# Make the plot using gnuplot epslatex terminal

# Calculate some dimensions: complicated version!
(( width = 3.375 )) # TOTAL width in inches 3.375
(( height = 2.4 )) # TOTAL height in inches (remember to factor in bgutter plus tgutter!)

# SPECIFY the gutters around the plots (in which the text has to sit) in INCHES, and CONVERT to SCREEN
(( lgutter = 0.1 / width ))
(( rgutter = 0.7 / width ))
(( bgutter = 0.25 / height ))
(( tgutter = 0.05 / height ))

(( bottom = 0.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( top = 1.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( left = 0.0 * (1.0-(lgutter+rgutter)) + lgutter ))
(( right = 1.0 * (1.0-(lgutter+rgutter)) + lgutter ))

###### Carve up the plot area in relative units, but CONVERT to SCREEN
((  gaph=0.01  ))
((  gapv=0.01  ))
((  gapv2=0.05  ))
((  ncol=2  ))
((  nrow=4  ))

(( row0 = bottom + 0.0*(top-bottom)/nrow ))
(( row1 = bottom + 1.0*(top-bottom)/nrow ))
(( row2 = bottom + 2.0*(top-bottom)/nrow ))
(( row3 = bottom + 3.0*(top-bottom)/nrow ))
(( row4 = bottom + 4.0*(top-bottom)/nrow ))
(( col1 = left+1.0*(right-left)/ncol ))
(( col2 = left+2.0*(right-left)/ncol ))

((  pwidth = col2-col1-haph  ))
((  pheight1=row4-row3-gapv  ))

echo  $(( pheight1* height ))

gnuplot << EOF
show version
set terminal epslatex dashed color size $((width)),$((height)) font 10
set output "${texfilestring}.tex"

set multiplot
unset key
set grid noxtics noytics front
set tics scale 0.5

#Plot 1
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row4))
set bmargin at screen $((row3+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(a)}" at 0.00, 0.88 front
set label "\\\color{white}{\$n_{+1}\$}" at 0.00, 0.12 front
set label "\$T_{\\\mathrm I}/T_{\\\mathrm C}\$" at screen $((0.6*left)), screen $((row3+gapv+pheight1/2.0)) front rotate center
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):1
unset label
unset arrow

#Plot 2
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row3))
set bmargin at screen $((row2+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "(b)" at 0.00, 0.88 front
set label "\$n_{0}\$" at 0.00, 0.12 front
set label "\$T_{\\\mathrm I}/T_{\\\mathrm C}\$" at screen $((0.6*left)), screen $((row2+gapv+pheight1/2.0)) front rotate center
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):2
unset label
unset arrow

#Plot 3
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row2))
set bmargin at screen $((row1+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(c)}" at 0.00, 0.88 front
set label "\\\color{white}{\$n_{-1}\$}" at 0.00, 0.12 front
set label "\$T_{\\\mathrm I}/T_{\\\mathrm C}\$" at screen $((0.6*left)), screen $((row1+gapv+pheight1/2.0)) front rotate center
set label "Time \$t/t_{\\\mathrm{f}} \$" at screen $((left+gaph+pwidth/2.0)), screen $((row1*0.95)) front center
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):3
unset label
unset arrow

#Plot 4
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row1-gapv2))
set bmargin at screen $((row0-gapv2+gapv))
set yrange [0:1.0]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "(d)" at 0.00, 1.1 front
set label "\$n_{i}(t_{\\\mathrm f})\$" at screen $((0.6*left)), screen $((bottom+gapv-gapv2+pheight1/2.0)) front rotate center
set label "Phase \$\\\delta_{\\\mathrm{S}}/2\\\pi=T_{\\\mathrm I}/T_{\\\mathrm C}\$" at screen $((left+gaph+pwidth/2.0)), screen $((row0*0.3)) front center
p './sag2.adat' u (\$7/78.53):1 w l ls 3 lc 2,\
  './sag2.adat' u (\$7/78.53):2 w l ls 1 lc 1,\
  './sag2.adat' u (\$7/78.53):3 w l ls 5 lc 3,\
  './sag_nf2.adat' u (\$7/78.53):2 w l ls 7 lc 0 
unset label
unset arrow

#Plot 5 
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row4))
set bmargin at screen $((row3+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(e)}" at 0.00, 0.88 front
set label "\\\color{white}{\$n_{+1}\$}" at 0.00, 0.12 front
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):1
unset label
unset arrow

#Plot 6
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row3))
set bmargin at screen $((row2+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "(f)" at 0.00, 0.88 front
set label "\$n_{0}\$" at 0.00, 0.12 front
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):2
unset label
unset arrow

#Plot 7
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row2))
set bmargin at screen $((row1+gapv))
set yrange [0:1.0]
set autoscale y
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(g)}" at 0.00, 0.88 front
set label "\\\color{white}{\$n_{-1}\$}" at 0.00, 0.12 front
set label "Time \$t/t_{\\\mathrm{f}} \$" at screen $((col1+gaph+pwidth/2.0)), screen $((row1*0.95)) front center
set cbrange [0:1.0]
set palette rgbformulae 23,22,21
set cbtics format "%.1f" offset -0.5,0.00
set colorbox user origin $((right+rgutter*0.4)),$((row1+gapv)) size 0.03,$((top-row1-gapv))
set cblabel "Total norm \$n_i(t)\$" offset -7.3,0.0
set palette rgbformulae 23,22,21
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):3
unset label
unset arrow

#Plot 8
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row1-gapv2))
set bmargin at screen $((row0-gapv2+gapv))
set yrange [0:1.0]
set key at 1.55, 2.2 samplen 3.0 spacing 2.75 height 8.0
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "(h)" at 0.00, 1.1 front
set label "Phase \$\\\delta_{\\\mathrm{Z}}/2\\\pi=T_{\\\mathrm I}/T_{\\\mathrm C}\$" at screen $((col1+gaph+pwidth/2.0)), screen $((row0*0.3)) front center
p './bfi2.adat' u (\$7/78.53):1 t "\$n_{+1}\$" w l ls 3 lc 2,\
  './bfi2.adat' u (\$7/78.53):2 t "\$n_0   \$" w l ls 1 lc 1,\
  './bfi2.adat' u (\$7/78.53):3 t "\$n_{-1}\$" w l ls 5 lc 3,\
  './bfi_nf2.adat' u (\$7/78.53):2 t "\$n_0^{\\\mathrm{nf}}\$" w l ls 7 lc 0 
unset label
unset arrow

unset multiplot
unset output
EOF

# If necessary, convert via a high-res png to bitmap format
#convert -density 1200 ${texfilestring}.eps ${texfilestring}.png
#rm ${texfilestring}.eps
#convert -density 1200 ${texfilestring}.png eps3:${texfilestring}.eps
#rm ${texfilestring}.png

# Make a blank tex input file to coax MikTeX's shite version of pdflatex into not writing to texput
echo > ${texfilestring}_blank.tex

#Run pdflatex on the output tex file, using the wrapper contained in this file to define fonts etc
latex -jobname=${texfilestring}_out << EOF
\input{./${texfilestring}_blank.tex}
\documentclass{article}
\usepackage[vcentering,dvips]{geometry}
\geometry{papersize={${width}in,${height}in},total={${width}in,${height}in}}
\usepackage{graphics}
\usepackage{nopageno}
\usepackage{txfonts}
\usepackage[usenames]{color}
\definecolor{reddish}{rgb}{1,0.1,0.1}
\definecolor{blueish}{rgb}{0,0.25,0.4}

\begin{document}
\footnotesize
\begin{center}
  \input{./${texfilestring}.tex}
\end{center}
\end{document}

EOF

# Remove the stupid blank file
rm ${texfilestring}_blank.tex

# Run dvips
dvips -o ${filestring}.ps ${texfilestring}_out.dvi

# Clean up output
rm ${texfilestring}_out.dvi ${texfilestring}_out.log ${texfilestring}_out.aux ${texfilestring}.tex ${texfilestring}.eps

# Convert to an eps
sed -i '1c\%!PS-Adobe-3.0 EPSF-3.0' ${filestring}.ps
mv ${filestring}.ps ${filestring}.eps

# Make a pdf version of for convenience
epstopdf ${filestring}.eps

# Make a png for quick compiling of the paper
convert -density 1000 ${filestring}.pdf ${filestring}.png

