#!/usr/bin/zsh

# Script to create a fully fledged figure from raw data,
# since figures always end up being more complicated than
# they were ever going to be when you wrote the code and 
# made the initial plots!

# See also some scripts for joining up completely
# separate plots into figures... somewhere!

# Root filename of figure
filestring="fig_over"

# Make a temporary filename without dots and with _tex appended
texfilestring=`echo ${filestring}_tex | sed 's/[.]/_/g'`

# Make the plot using gnuplot epslatex terminal

# Calculate some dimensions: complicated version!
(( width = 3.375 )) # TOTAL width in inches 3.375
(( height = 1.7555 )) # TOTAL height in inches (remember to factor in bgutter plus tgutter!)

# SPECIFY the gutters around the plots (in which the text has to sit) in INCHES, and CONVERT to SCREEN
(( lgutter = 0.2 / width ))
(( rgutter = 0.7 / width ))
(( bgutter = 0.11 / height ))
(( tgutter = 0.05 / height ))

(( bottom = 0.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( top = 1.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( left = 0.0 * (1.0-(lgutter+rgutter)) + lgutter ))
(( right = 1.0 * (1.0-(lgutter+rgutter)) + lgutter ))

###### Carve up the plot area in relative units, but CONVERT to SCREEN
((  gaph=0.01  ))
((  gapv=0.01  ))
((  gapv2=0.0  ))
((  ncol=2  ))
((  nrow=3  ))

(( row0 = bottom + 0.0*(top-bottom)/nrow ))
(( row1 = bottom + 1.0*(top-bottom)/nrow ))
(( row2 = bottom + 2.0*(top-bottom)/nrow ))
(( row3 = bottom + 3.0*(top-bottom)/nrow ))
(( row4 = bottom + 4.0*(top-bottom)/nrow ))
(( col1 = left+1.0*(right-left)/ncol ))
(( col2 = left+2.0*(right-left)/ncol ))

((  pwidth = col2-col1-haph  ))
((  pheight1=row3-row2-gapv  ))

echo $(( pheight1*height ))

gnuplot << EOF
show version
set terminal epslatex dashed color size $((width)),$((height)) font 10
set output "${texfilestring}.tex"

set multiplot
unset key
set grid noxtics noytics front
set tics scale 0.5

#Plot 1
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row3))
set bmargin at screen $((row2+gapv))
set autoscale y
set xrange [0:1.0]
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(a)}" at 0.00, 0.88 front
set label "\\\color{white}{\$\\\chi_{+1,0}\$}" at 0.2, 0.88 front
set label "\$\\\delta_{\\\mathrm{S,Z}}/2\\\pi\$" at screen $((0.5*left)), screen $((row2+gapv+pheight1/2.0)) front rotate center
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):(\$8/0.12)
unset label
unset arrow

#Plot 2
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row2))
set bmargin at screen $((row1+gapv))
set autoscale y
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(b)}" at 0.00, 0.88 front
set label "\\\color{black}{\$\\\chi_{+1,-1}\$}" at 0.2, 0.88 front
set label "\$\\\delta_{\\\mathrm{S,Z}}/2\\\pi\$" at screen $((0.5*left)), screen $((row1+gapv+pheight1/2.0)) front rotate center
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):(\$9/0.12)
unset label
unset arrow

#Plot 3
set lmargin at screen $((left+gaph))
set rmargin at screen $((col1))
set tmargin at screen $((row1))
set bmargin at screen $((row0+gapv))
set autoscale y
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(c)}" at 0.00, 0.88 front
set label "\\\color{white}{\$\\\chi_{-1,0}\$}" at 0.2, 0.88 front
set label "\$\\\delta_{\\\mathrm{S,Z}}/2\\\pi\$" at screen $((0.5*left)), screen $((row0+gapv+pheight1/2.0)) front rotate center
set label "Time \$t/t_{\\\mathrm{f}} \$" at screen $((left+gaph+pwidth/2.0)), screen $((row0*0.4)) front center
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './sag.adat' u 6:(\$7/78.53):(\$10/0.12)
unset label
unset arrow

##Plot 4
#set lmargin at screen $((left+gaph))
#set rmargin at screen $((col1))
#set tmargin at screen $((row1-gapv2))
#set bmargin at screen $((row0-gapv2+gapv))
#set yrange [0:1]
#set ytics 0,0.12,0.12 format "%.2f" offset 0.5 
#set xtics 0,0.5,1.0 format " "
#set label "(d)" at 0.00, 0.133 front
#set label "\$\\\chi_{i,j}\$" at screen $((0.5*left)), screen $((bottom+gapv-gapv2+pheight1/2.0)) front rotate center
#set label "\$\\\chi_{1,0}\$" at 0.3,0.03 front center
#p './sag_0.3000.adat' u 6:(\$10/0.12) w l lt 1,\
#  './sag_0.5000.adat' u 6:(\$10/0.12) w l lt 2,\
#  './sag_0.7000.adat' u 6:(\$10/0.12) w l lt 3,\
#  './sag_1.0000.adat' u 6:(\$10/0.12) w l lt 5
#unset label
#unset arrow

#Plot5 
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row3))
set bmargin at screen $((row2+gapv))
set autoscale y
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(d)}" at 0.00, 0.88 front
set label "\\\color{white}{\$\\\chi_{+1,0}\$}" at 0.2, 0.88 front
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):(\$8/0.12)
unset label
unset arrow

#Plot 6
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row2))
set bmargin at screen $((row1+gapv))
set autoscale y
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(e)}" at 0.00, 0.88 front
set label "\\\color{black}{\$\\\chi_{+1,-1}\$}" at 0.2, 0.88 front
set palette rgbformulae 23,22,21
unset colorbox
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):(\$9/0.12)
unset label
unset arrow

#Plot 7
set lmargin at screen $((col1+gaph))
set rmargin at screen $((col2))
set tmargin at screen $((row1))
set bmargin at screen $((row0+gapv))
set autoscale y
set cbrange [0:1]
set ytics 0,0.5,1.0 format " "
set xtics 0,0.5,1.0 format " "
set label "\\\color{white}{(f)}" at 0.00, 0.88 front
set label "\\\color{white}{\$\\\chi_{-1,0}\$}" at 0.2, 0.88 front
set label "Time \$t/t_{\\\mathrm{f}} \$" at screen $((col1+gaph+pwidth/2.0)), screen $((row0*0.4)) front center
set palette rgbformulae 23,22,21
set cbtics format "%.1f" offset -0.5,0.00
set colorbox user origin $((right+rgutter*0.4)),$((row0+gapv)) size 0.03,$((top-row0-gapv))
set cblabel "Spatial overlap \$\\\chi_{i,j}/\\\chi_\\\mathrm{max}\$" offset -7.8,0.0
set palette rgbformulae 23,22,21
set pm3d map
splot './bfi.adat' u 6:(\$7/78.53):(\$10/0.12)
unset label
unset arrow

##Plot 8
#set lmargin at screen $((col1+gaph))
#set rmargin at screen $((col2))
#set tmargin at screen $((row1-gapv2))
#set bmargin at screen $((row0-gapv2+gapv))
#set yrange [0:1]
#set key at 1.55, 0.3  samplen 3.0 spacing 3.0 height 10
#set ytics 0,0.5,1.0 format " "
#set xtics 0,0.5,1.0 format " "
#set label "\$\\\chi_{-1,1}\$" at 0.3,0.03 front center
#set label "(h)" at 0.00, 0.133 front
#p './bfi_0.3000.adat' u 6:(\$9/0.12) t "\$0.3\$" w l lt 1,\
#  './bfi_0.5000.adat' u 6:(\$9/0.12) t "\$0.5\$" w l lt 2,\
#  './bfi_0.7000.adat' u 6:(\$9/0.12) t "\$0.7\$" w l lt 3,\
#  './bfi_1.0000.adat' u 6:(\$9/0.12) t "\$1.0\$" w l lt 5
#unset label
#unset arrow

unset multiplot
unset output
EOF

# If necessary, convert via a high-res png to bitmap format
#convert -density 1200 ${texfilestring}.eps ${texfilestring}.png
#rm ${texfilestring}.eps
#convert -density 1200 ${texfilestring}.png eps3:${texfilestring}.eps
#rm ${texfilestring}.png

# Make a blank tex input file to coax MikTeX's shite version of pdflatex into not writing to texput
echo > ${texfilestring}_blank.tex

#Run pdflatex on the output tex file, using the wrapper contained in this file to define fonts etc
latex -jobname=${texfilestring}_out << EOF
\input{./${texfilestring}_blank.tex}
\documentclass{article}
\usepackage[vcentering,dvips]{geometry}
\geometry{papersize={${width}in,${height}in},total={${width}in,${height}in}}
\usepackage{graphics}
\usepackage{nopageno}
\usepackage{txfonts}
\usepackage[usenames]{color}
\definecolor{reddish}{rgb}{1,0.1,0.1}
\definecolor{blueish}{rgb}{0,0.25,0.4}

\begin{document}
\footnotesize
\begin{center}
  \input{./${texfilestring}.tex}
\end{center}
\end{document}

EOF

# Remove the stupid blank file
rm ${texfilestring}_blank.tex

# Run dvips
dvips -o ${filestring}.ps ${texfilestring}_out.dvi

# Clean up output
rm ${texfilestring}_out.dvi ${texfilestring}_out.log ${texfilestring}_out.aux ${texfilestring}.tex ${texfilestring}.eps

# Convert to an eps
sed -i '1c\%!PS-Adobe-3.0 EPSF-3.0' ${filestring}.ps
mv ${filestring}.ps ${filestring}.eps

# Make a pdf version of for convenience
epstopdf ${filestring}.eps

# Make a png for quick compiling of the paper
convert -density 1000 ${filestring}.pdf ${filestring}.png

