#!/usr/bin/zsh

# Script to create a fully fledged figure from raw data,
# since figures always end up being more complicated than
# they were ever going to be when you wrote the code and 
# made the initial plots!

# See also some scripts for joining up completely
# separate plots into figures... somewhere!

# Root filename of figure
filestring="fig_schem"

# Make a temporary filename without dots and with _tex appended
texfilestring=`echo ${filestring}_tex | sed 's/[.]/_/g'`

# Make the plot using gnuplot epslatex terminal

# Calculate some dimensions: complicated version!
(( width = 3.375 )) # TOTAL width in inches 3.375
(( height = 2.0 )) # TOTAL height in inches (remember to factor in bgutter plus tgutter!)

# SPECIFY the gutters around the plots (in which the text has to sit) in INCHES, and CONVERT to SCREEN
(( lgutter = 0.33 / width ))
(( rgutter = 0.6 / width ))
(( bgutter = 0.06 / height ))
(( tgutter = 0.1 / height ))

(( bottom = 0.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( top = 1.0 * (1.0-(tgutter+bgutter)) + bgutter ))
(( left = 0.0 * (1.0-(lgutter+rgutter)) + lgutter ))
(( right = 1.0 * (1.0-(lgutter+rgutter)) + lgutter ))
###### Carve up the plot area in relative units, but CONVERT to SCREEN
((  gap=0.08  ))
((  ncol=1.0  ))
((  nrow=3.0  ))

(( row1 = bottom + 2.0*(top-bottom)/nrow ))
(( row2 = bottom + 1.0*(top-bottom)/nrow ))
(( row3 = bottom + 0.0*(top-bottom)/nrow ))
(( col1 = left+1.0*(right-left)/ncol ))
(( col2 = left+2.0*(right-left)/ncol ))
(( col3 = left+3.0*(right-left)/ncol ))

((  pwidth =(left-right)/ncol  ))
((  pheight1=top-row1+gap  ))
((  pheight2=row1-bottom  ))

gnuplot << EOF
show version
set terminal epslatex dashed color size $((width)),$((height)) solid font 10
set output "${texfilestring}.tex"

set multiplot
unset key
set grid noxtics noytics front
set tics scale 0.5


#Plot 1
set lmargin at screen $((left))
set rmargin at screen $((right))
set tmargin at screen $((top))
set bmargin at screen $((row1+gap))
#set autoscale x
set yrange [-1.2:1.2]
set xrange [0:1]
set xtics 0,0.25,1.0 format " " 
set ytics -1,1.0,1.0 format "%.1f" offset 0.5,-0.1
set label "(a)" at 0.0, 1.4 front
set label "\$B(t)/B(0)\$" at screen $((0.03)), screen $((row1+pheight1/2.0)) front rotate center
set label at  0.9,-0.5 front center
set label at  0.9, 0.7 front center
set key at screen $((0.99)), screen $((row1+gap+pheight1*1.125)) samplen 3.0 spacing 3.0 height 11
rampu(x,l,s)=0.5*(1.0+tanh(6.0*(x-l)/s))
rampd(x,l,s)=0.5*(1.0+tanh(-6.0*(x-l)/s))
ttot=119.662
pump_t=16.0784/ttot
ramp_t=39.2699/ttot
stand_t=16.0784/ttot
bz(x)=rampd(x,0.5*pump_t,pump_t)-rampu(x,ramp_t+3.5*pump_t,pump_t)
bp(x)=rampd(x,1.5*pump_t,pump_t)+rampu(x,ramp_t+2.5*pump_t,pump_t)
set obj 1 rect from graph 0, graph -1.2 to graph pump_t, graph 1.2 fs solid 0.15 noborder fc rgb "#FFD700" behind 
set obj 2 rect from graph 3*pump_t+ramp_t, graph -1.2 to graph 4*pump_t+ramp_t, graph 1.2 fs solid 0.15 noborder fc rgb "#FFD700" behind 
set obj 3 rect from graph pump_t, graph -1.2 to graph 2*pump_t, graph 1.2 fs solid 0.15 noborder fc rgb "#FB2C8" behind 
set obj 4 rect from graph 2*pump_t+ramp_t, graph -1.2 to graph 3*pump_t+ramp_t, graph 1.2 fs solid 0.15 noborder fc rgb "#FB2C8" behind 
p bz(x) t "\$B_z\$"       w l lw 3 lt 1,\
  bp(x) t "\$B_{\\\mathrm q}\$" w l lw 3 lt 2
unset label
unset arrow

#Plot 2
set lmargin at screen $((left))
set rmargin at screen $((right))
set tmargin at screen $((row1))
set bmargin at screen $((row2+gap))
set yrange [-0.1:1.1]
set xrange [0:1.0]
set xtics 0,0.5,1.0 format " " 
set ytics 0,0.5,1.0 format "%.1f" offset 0.75,-0.1
set label "(b)" at 0.0, 1.22 front
set label "\$n_i\$" at screen $((0.03)), screen $((row2+pheight1/2.0)) front rotate center 
set key at screen $((0.99)), screen $((row2+pheight1*1.6125)) samplen 3.0 spacing 3.0 height 15
p './sag_0.5000.adat' u 6:1 t "\$n_{+1}\$" w l lw 3 lt 1,\
  './sag_0.5000.adat' u 6:2 t "\$n_{ 0}\$" w l lw 3 lt 2,\
  './sag_0.5000.adat' u 6:3 t "\$n_{-1}\$" w l lw 3 lt 5 lc 3 
unset label
unset arrow

#Plot 3
set lmargin at screen $((left))
set rmargin at screen $((right))
set tmargin at screen $((row2))
set bmargin at screen $((row3+gap))
set yrange [-0.0833:1.0833]
set xrange [0:1.0]
set xtics 0,0.25,2.0 format "%.1f" 
set ytics 0,1.0,1.0 format "%.1f" offset 0.75,-0.1
set label "(c)" at 0.0, 1.19 front
set key at screen $((0.99)), screen $((row3+pheight1*1.6125)) samplen 3.0 spacing 3.0 
set label "\$\\\chi_{i,j}/\\\chi_\\\mathrm{max}\$" at screen $((0.03)), screen $((row3+pheight1/2.0)) front rotate center
set label "Time \$t/t_{\\\mathrm{f}}\$" at screen $((left+(right-left)/2.0)), screen $((0.03)) front center 
p './sag_0.5000.adat' u 6:(\$8/0.12)  t "\$\\\chi_{-1,0}\$" w l lw 3 lt 1,\
  './sag_0.5000.adat' u 6:(\$9/0.12)  t "\$\\\chi_{-1,1}\$" w l lw 3 lt 2,\
  './sag_0.5000.adat' u 6:(\$10/0.12) t "\$\\\chi_{0,1}\$"  w l lw 3 lt 5 lc 3 
unset label
unset arrow

EOF

# If necessary, convert via a high-res png to bitmap format
#convert -density 1200 ${texfilestring}.eps ${texfilestring}.png
#rm ${texfilestring}.eps
#convert -density 1200 ${texfilestring}.png eps3:${texfilestring}.eps
#rm ${texfilestring}.png

# Make a blank tex input file to coax MikTeX's shite version of pdflatex into not writing to texput
echo > ${texfilestring}_blank.tex

#Run pdflatex on the output tex file, using the wrapper contained in this file to define fonts etc
latex -jobname=${texfilestring}_out << EOF
\input{./${texfilestring}_blank.tex}
\documentclass{article}
\usepackage[vcentering,dvips]{geometry}
\geometry{papersize={${width}in,${height}in},total={${width}in,${height}in}}
\usepackage{graphics}
\usepackage{nopageno}
\usepackage{txfonts}
\usepackage[usenames]{color}
\definecolor{reddish}{rgb}{1,0.1,0.1}
\definecolor{blueish}{rgb}{0,0.25,0.4}

\begin{document}
\footnotesize
\begin{center}
  \input{./${texfilestring}.tex}
\end{center}
\end{document}

EOF

# Remove the stupid blank file
rm ${texfilestring}_blank.tex

# Run dvips
dvips -o ${filestring}.ps ${texfilestring}_out.dvi

# Clean up output
rm ${texfilestring}_out.dvi ${texfilestring}_out.log ${texfilestring}_out.aux ${texfilestring}.tex ${texfilestring}.eps

# Convert to an eps
sed -i '1c\%!PS-Adobe-3.0 EPSF-3.0' ${filestring}.ps
mv ${filestring}.ps ${filestring}.eps

# Make a pdf version of for convenience
epstopdf ${filestring}.eps

# Make a png for quick compiling of the paper
convert -density 1000 ${filestring}.pdf ${filestring}.png

